from time import sleep
from typing import Optional

from audiostack.helpers.api_item import APIResponseItem
from audiostack.helpers.api_list import APIResponseList
from audiostack.helpers.request_interface import RequestInterface
from audiostack.helpers.request_types import RequestTypes


class STS:
    interface = RequestInterface(family="speech/sts")

    class StsVoiceItem(APIResponseItem):
        def __init__(self, response: dict) -> None:
            super().__init__(response)
            self.provider = self.data["provider"]
            self.alias = self.data["alias"]
            self.language = self.data["language"]
            self.languageCode = self.data["languageCode"]

    class StsVoiceList(APIResponseList):
        def __init__(self, response: dict, list_type: str) -> None:
            super().__init__(response, list_type)

        def resolve_item(self, list_type: str, x: int) -> APIResponseItem:
            return self.data[list_type][x]

    class FailedPipeline(Exception):
        pass

    class FailedStatusFetch(Exception):
        pass

    class PipelineInProgressItem(APIResponseItem):
        def __init__(self, response: dict) -> None:
            super().__init__(response)
            self.pipelineId = self.data["pipelineId"]

    class PipelineFinishedItem(APIResponseItem):
        def __init__(self, response: dict) -> None:
            super().__init__(response)
            self.pipelineId = self.data["pipelineId"]
            self.newFileIds = self.data["results"]["newFileIds"]
            self.inputFileIds = self.data["results"]["inputFileIds"]
            self.replacedFileIds = self.data["results"]["replacedFileIds"]

    @staticmethod
    def voices() -> APIResponseList:
        r = STS.interface.send_request(rtype=RequestTypes.GET, route="voices")
        return STS.StsVoiceList(r, list_type="voices")

    @staticmethod
    def create(
        alias: str, fileId: str, newFilePath: Optional[str] = None
    ) -> PipelineInProgressItem:
        body = {"alias": alias, "fileId": fileId}
        if newFilePath:
            body["newFilePath"] = newFilePath
        r = STS.interface.send_request(rtype=RequestTypes.POST, route="", json=body)
        item = STS.PipelineInProgressItem(r)
        return item

    @staticmethod
    def get(pipelineId: str) -> PipelineFinishedItem:
        r = STS.interface.send_request(
            rtype=RequestTypes.GET, route="", path_parameters=pipelineId
        )

        if r["data"]["status"] in [200, 202]:
            return STS._poll(r, pipelineId)
        else:
            body = r["data"]["body"]
            raise STS.FailedStatusFetch(f"Failed to fetch pipeline with error: {body}")

    @staticmethod
    def _poll(r: dict, pipelineId: str) -> PipelineFinishedItem:
        pipeline_status_code = r["data"]["status"]
        while pipeline_status_code == 202:
            print("Waiting for pipeline to complete (0.5 seconds)...")
            sleep(0.5)
            r = STS.interface.send_request(
                rtype=RequestTypes.GET, route="", path_parameters=pipelineId
            )
            pipeline_status_code = r["data"]["status"]

        status = r.get("data", {}).get("status", 200)
        if status >= 400:
            msg = r.get("data", {}).get("message")
            errors = r.get("data", {}).get("errors")
            raise STS.FailedPipeline(
                "pipeline failed: ", msg, "errors are as follows: ", ",".join(errors)
            )

        return STS.PipelineFinishedItem(r)



import os

import audiostack
from audiostack.speech.voice import Voice

audiostack.api_base = os.environ.get("AUDIO_STACK_DEV_URL", "https://v2.api.audio")
audiostack.api_key = os.environ["AUDIO_STACK_DEV_KEY"]  # type: ignore


def test_list() -> None:
    voices = Voice.list()
    for v in voices:
        assert isinstance(v, Voice.Item)
        assert v.provider
        assert v.alias
        assert v.data


def test_parmaters() -> None:
    r = Voice.Parameter.get()
    assert r



import json


class Response:
    statusCode: int

    # mututally exclusive
    errors: list = []
    data: dict = {}

    meta: dict
    message: str
    warnings: list

    def __repr__(self) -> str:
        if self.statusCode >= 200:
            return json.dumps({"data": self.data})
        else:
            return ""

    def __str__(self) -> str:
        return "member of Test"



from typing import Any, Union

from audiostack.helpers.api_item import APIResponseItem
from audiostack.helpers.api_list import APIResponseList
from audiostack.helpers.request_interface import RequestInterface
from audiostack.helpers.request_types import RequestTypes


class Sound:
    interface = RequestInterface(family="production/sound")

    # ----------------------------------------- TEMPLATE -----------------------------------------
    class Template:
        class Item(APIResponseItem):
            def __init__(self, response: dict) -> None:
                super().__init__(response)

                if "template" in self.data:  #
                    self.data = self.data["template"]

        class List(APIResponseList):
            def __init__(self, response: dict, list_type: str) -> None:
                super().__init__(response, list_type)

            def resolve_item(self, list_type: str, item: Any) -> "Sound.Template.Item":
                if list_type == "templates":
                    return Sound.Template.Item(
                        {"data": item, "statusCode": self.response["statusCode"]}
                    )
                else:
                    raise Exception()

        @staticmethod
        def select_for_script(
            scriptId: str = "", scriptItem: Any = "", mood: str = ""
        ) -> APIResponseItem:
            if scriptId and scriptItem:
                raise Exception("scriptId or scriptItem should be supplied not both")
            if not (scriptId or scriptItem):
                raise Exception("scriptId or scriptItem should be supplied")

            if scriptItem:
                scriptId = scriptItem.scriptId

            body = {"scriptId": scriptId, "mood": mood}

            r = Sound.interface.send_request(
                rtype=RequestTypes.POST, route="select", json=body
            )
            return APIResponseItem(response=r)

        @staticmethod
        def select_for_content(content: str, mood: str = "") -> APIResponseItem:
            body = {"content": content}
            if mood:
                body["mood"] = mood

            r = Sound.interface.send_request(
                rtype=RequestTypes.POST, route="select", json=body
            )
            return APIResponseItem(response=r)

        @staticmethod
        def list(
            collections: Union[str, list] = "",
            genres: Union[str, list] = "",
            instruments: Union[str, list] = "",
            moods: str = "",
        ) -> "Sound.Template.List":
            query_params = {
                "moods": moods,
                "collections": collections,
                "instruments": instruments,
                "genres": genres,
            }
            r = Sound.interface.send_request(
                rtype=RequestTypes.GET, route="template", query_parameters=query_params
            )
            return Sound.Template.List(r, list_type="templates")

        @staticmethod
        def create(templateName: str, description: str = "") -> "Sound.Template.Item":
            body = {"templateName": templateName, "description": description}
            r = Sound.interface.send_request(
                rtype=RequestTypes.POST, route="template", json=body
            )
            return Sound.Template.Item(r)

        @staticmethod
        def delete(templateName: str) -> APIResponseItem:
            r = Sound.interface.send_request(
                rtype=RequestTypes.DELETE,
                route="template",
                path_parameters=templateName,
            )
            return APIResponseItem(r)

    # ----------------------------------------- TEMPLATE SEGMENT -----------------------------------------
    class Segment:
        @staticmethod
        def create(
            mediaId: str, templateName: str, soundSegmentName: str
        ) -> "Sound.Template.Item":
            segment = {
                "templateName": templateName,
                "segmentName": soundSegmentName,
                "mediaId": mediaId,
            }
            r = Sound.interface.send_request(
                rtype=RequestTypes.POST, route="segment", json=segment
            )
            return Sound.Template.Item(r)

    # ----------------------------------------- TEMPLATE PARAMETERS -----------------------------------------
    class Parameter:
        @staticmethod
        def get() -> APIResponseItem:
            r = Sound.interface.send_request(rtype=RequestTypes.GET, route="parameter")
            return APIResponseItem(r)



from typing import Any

from audiostack.helpers.api_item import APIResponseItem
from audiostack.helpers.api_list import APIResponseList
from audiostack.helpers.request_interface import RequestInterface
from audiostack.helpers.request_types import RequestTypes


class Predict:
    interface = RequestInterface(family="speech/predict")

    class Item(APIResponseItem):
        def __init__(self, response: dict) -> None:
            super().__init__(response)

            self.length = self.data["length"]

    class List(APIResponseList):
        def __init__(self, response: dict, list_type: str) -> None:
            super().__init__(response, list_type)

        def resolve_item(self, list_type: str, item: Any) -> "Predict.Item":
            if list_type == "voices":
                return item
            else:
                raise Exception()

    @staticmethod
    def list() -> "Predict.List":
        r = Predict.interface.send_request(rtype=RequestTypes.GET, route="voices")
        return Predict.List(response=r, list_type="voices")

    @staticmethod
    def predict(text: str, voice: str) -> "Predict.Item":
        body = {"text": text, "voice": voice}
        r = Predict.interface.send_request(rtype=RequestTypes.POST, route="", json=body)
        return Predict.Item(r)



from typing import Any, Optional

from audiostack.helpers.api_item import APIResponseItem
from audiostack.helpers.api_list import APIResponseList
from audiostack.helpers.request_interface import RequestInterface
from audiostack.helpers.request_types import RequestTypes


class Encoder:
    interface = RequestInterface(family="delivery")

    class Item(APIResponseItem):
        def __init__(self, response: dict) -> None:
            super().__init__(response)
            self.url = self.data["url"]
            self.format = self.data["format"]

        def download(self, fileName: str = "default", path: str = "./") -> None:
            full_name = f"{fileName}.{self.format}"
            RequestInterface.download_url(self.url, destination=path, name=full_name)

    class List(APIResponseList):
        def __init__(self, response: dict, list_type: str) -> None:
            super().__init__(response, list_type)

        def resolve_item(self, list_type: str, item: Any) -> "Encoder.Item":
            if list_type == "encodedItems":
                return Encoder.Item({"data": item})
            else:
                raise Exception()

    @staticmethod
    def encode_mix(
        preset: str,
        productionId: str = "",
        productionItem: Optional[Any] = None,
        loudnessPreset: str = "",
        public: bool = False,
        bitRateType: str = "",
        bitRate: Optional[int] = None,
        sampleRate: Optional[int] = None,
        format: str = "",
        bitDepth: Optional[int] = None,
        channels: Optional[int] = None,
    ) -> Item:
        if productionId and productionItem:
            raise Exception(
                "productionId or productionItem should be supplied not both"
            )
        if not (productionId or productionItem):
            raise Exception("productionId or productionItem should be supplied")

        if productionItem:
            try:
                productionId = productionItem.productionId
            except Exception:
                raise Exception(
                    "supplied productionItem is missing an attribute, productionItem should be type object and a response from Production.Mix"
                )
        elif productionId:
            if not isinstance(productionId, str):
                raise Exception("supplied productionId should be a uuid string.")

        if not preset:
            raise Exception(
                "Either a an encoding preset (preset) or a loudness preset (loudnessPreset) should be supplied"
            )

        body = {
            "productionId": productionId,
            "preset": preset,
            "public": public,
            "bitRateType": bitRateType,
            "bitRate": bitRate,
            "sampleRate": sampleRate,
            "format": format,
            "bitDepth": bitDepth,
            "channels": channels,
            "loudnessPreset": loudnessPreset,
        }
        r = Encoder.interface.send_request(
            rtype=RequestTypes.POST, route="encoder", json=body
        )

        while r["statusCode"] == 202:
            print("Response in progress please wait...")
            encoderId = r["data"]["encoderId"]
            r = Encoder.interface.send_request(
                rtype=RequestTypes.GET, route="encoder", path_parameters=encoderId
            )
        return Encoder.Item(r)

    @staticmethod
    def list_presets() -> "Encoder.List":
        r = Encoder.interface.send_request(
            rtype=RequestTypes.GET, route="encoder/presets", path_parameters=""
        )
        return Encoder.List(response=r, list_type="presets")



from typing import Any
from unittest.mock import Mock, call, patch

import pytest
from pytest import fixture

from audiostack.speech.sts import STS


@fixture
def voice_data() -> dict:
    return {
        "provider": "provider",
        "alias": "alias",
        "language": "language",
        "languageCode": "languageCode",
    }


@fixture
def pipelineFinishedItem_data() -> dict:
    return {
        "pipelineId": "pipelineId",
        "results": {
            "newFileIds": "newFileIds",
            "inputFileIds": "inputFileIds",
            "replacedFileIds": "replacedFileIds",
        },
    }


@fixture
def mock_send_request() -> Any:
    with patch("audiostack.speech.STS.interface.send_request") as mock_:
        yield mock_


@fixture
def mock__poll() -> Any:
    with patch("audiostack.speech.STS._poll") as mock_:
        yield mock_


def test_Sts_family() -> None:
    assert STS.interface.family == "speech/sts"


def test_StsVoiceItem(voice_data: dict) -> None:
    response = {"data": voice_data}
    item = STS.StsVoiceItem(response=response)
    assert item.provider == voice_data["provider"]
    assert item.alias == voice_data["alias"]
    assert item.language == voice_data["language"]
    assert item.languageCode == voice_data["languageCode"]
    assert item.response == response


def test_PipelineInProgressItem() -> None:
    response = {"data": {"pipelineId": "pipelineId"}}
    item = STS.PipelineInProgressItem(response=response)
    assert item.pipelineId == "pipelineId"
    assert item.response == response


def test_PipelineFinishedItem(pipelineFinishedItem_data: dict) -> None:
    response = {"data": pipelineFinishedItem_data}
    item = STS.PipelineFinishedItem(response=response)
    assert item.pipelineId == "pipelineId"
    assert item.inputFileIds == "inputFileIds"
    assert item.replacedFileIds == "replacedFileIds"
    assert item.response == response


def test_STS_voices(mock_send_request: Mock, voice_data: dict) -> None:
    mock_send_request.return_value = {"data": {"voices": [voice_data] * 10}}

    r = STS.voices()
    mock_send_request.assert_called_once_with(rtype="GET", route="voices")
    item = r[0]
    # assert item.provider == "provider" # fails
    assert item["provider"] == voice_data["provider"]
    assert item["alias"] == voice_data["alias"]
    assert item["language"] == voice_data["language"]
    assert item["languageCode"] == voice_data["languageCode"]


def test_STS_create(mock_send_request: Mock) -> None:
    alias = "alias"
    fileId = "fileId"
    mock_send_request.return_value = {"data": {"pipelineId": "pipelineId"}}
    r = STS.create(alias=alias, fileId=fileId)
    mock_send_request.assert_called_once_with(
        rtype="POST", route="", json={"alias": "alias", "fileId": "fileId"}
    )
    assert isinstance(r, STS.PipelineInProgressItem)
    assert r.pipelineId == "pipelineId"


def test_STS_create_newFilePath(mock_send_request: Mock) -> None:
    alias = "alias"
    fileId = "fileId"
    newFilePath = "newFilePath"
    mock_send_request.return_value = {"data": {"pipelineId": "pipelineId"}}
    r = STS.create(alias=alias, fileId=fileId, newFilePath=newFilePath)
    mock_send_request.assert_called_once_with(
        rtype="POST",
        route="",
        json={"alias": "alias", "fileId": "fileId", "newFilePath": "newFilePath"},
    )
    assert isinstance(r, STS.PipelineInProgressItem)
    assert r.pipelineId == "pipelineId"


@pytest.mark.parametrize("status_code", [200, 202])
def test_STS_get(
    mock_send_request: Mock,
    mock__poll: Mock,
    pipelineFinishedItem_data: dict,
    status_code: int,
) -> None:
    pipelineId = "pipelineId"
    mock_data = {**{"status": status_code}, **pipelineFinishedItem_data}
    mock_send_request.return_value = {"data": mock_data}
    mock__poll.return_value = STS.PipelineFinishedItem({"data": mock_data})
    r = STS.get(pipelineId=pipelineId)
    mock_send_request.assert_called_once_with(
        rtype="GET", route="", path_parameters=pipelineId
    )
    assert r == mock__poll.return_value


def test_STS_get_raises_FailedStatusFetch(mock_send_request: Mock) -> None:
    pipelineId = "pipelineId"
    mock_send_request.return_value = {"data": {"status": 404, "body": "error message"}}

    with pytest.raises(STS.FailedStatusFetch) as exc:
        STS.get(pipelineId=pipelineId)

    assert str(exc.value) == "Failed to fetch pipeline with error: error message"


def test_STS__poll(mock_send_request: Mock, pipelineFinishedItem_data: dict) -> None:
    r = {"data": {"status": 202}}

    # with statusCode 202 the request is executed again until it gets 200
    return_value_1 = {"data": {**{"status": 202}, **pipelineFinishedItem_data}}
    return_value_2 = {"data": {**{"status": 200}, **pipelineFinishedItem_data}}
    mock_send_request.side_effect = [return_value_1, return_value_2]

    response = STS._poll(r=r, pipelineId="pipelineId")
    mock_send_request.assert_has_calls(
        [
            call(rtype="GET", route="", path_parameters="pipelineId"),
            call(rtype="GET", route="", path_parameters="pipelineId"),
        ]
    )
    assert isinstance(response, STS.PipelineFinishedItem)
    assert response.data == return_value_2["data"]


def test_STS__poll_400(
    mock_send_request: Mock, pipelineFinishedItem_data: dict
) -> None:
    r = {"data": {**{"status": 202}, **pipelineFinishedItem_data}}

    mock_send_request.return_value = {
        "data": {
            "status": 404,
            "message": "message",
            "errors": "errors",
        }
    }

    with pytest.raises(STS.FailedPipeline):
        STS._poll(r=r, pipelineId="pipelineId")



import os
from unittest.mock import patch

import audiostack
from audiostack.content.file import File
from audiostack.production.suite import Suite

audiostack.api_base = os.environ.get("AUDIO_STACK_DEV_URL", "https://v2.api.audio")
audiostack.api_key = os.environ["AUDIO_STACK_DEV_KEY"]  # type: ignore

test_constants = {}


def test_create() -> None:
    r = File.create(localPath="example.mp3", uploadPath="example.mp3", fileType="audio")
    test_constants["fileId"] = r.fileId
    print(r)


def test_denoise() -> None:
    with patch("audiostack.production.suite.Suite.DENOISE_ENDPOINT", "suite/test"):
        r = Suite.denoise(test_constants["fileId"], wait=False)
        assert isinstance(r, Suite.PipelineInProgressItem)
        test_constants["pipelineId"] = r.pipelineId


def test_get() -> None:
    r = Suite.get(test_constants["pipelineId"])
    assert isinstance(r, Suite.PipelineFinishedItem)
    for f in r.convert_new_files_to_items():
        f.download()



from typing import Any, Optional, Union

from audiostack.helpers.api_item import APIResponseItem
from audiostack.helpers.api_list import APIResponseList
from audiostack.helpers.request_interface import RequestInterface
from audiostack.helpers.request_types import RequestTypes


class Mix:
    interface = RequestInterface(family="production")

    class Item(APIResponseItem):
        def __init__(self, response: dict) -> None:
            super().__init__(response)
            self.productionId = self.data["productionId"]

        def download(self, fileName: str = "", path: str = "./") -> None:
            sections = self.data["files"]
            for i, s in enumerate(sections):
                format = s["format"]
                original_name = s["filename"]

                if not fileName:
                    full_name = f"{original_name}.{format}"
                else:
                    full_name = f"{fileName}_{i}.{format}"

                RequestInterface.download_url(
                    s["url"], destination=path, name=full_name
                )

        def delete(self) -> APIResponseItem:
            return Mix.delete(self.productionId)

    class List(APIResponseList):
        def __init__(self, response: dict, list_type: str) -> None:
            super().__init__(response, list_type)

        def resolve_item(self, list_type: str, item: Any) -> Union["Mix.Item", None]:
            if list_type == "productionIds":
                return Mix.Item({"data": item})
            elif list_type == "presets":
                return None
            else:
                raise Exception()

    @staticmethod
    def create(
        speechId: str = "",
        scriptId: str = "",
        speechItem: Optional[Any] = None,
        soundTemplate: str = "",
        mediaFiles: dict = {},
        fxFiles: dict = {},
        sectionProperties: dict = {},
        timelineProperties: dict = {},
        masteringPreset: str = "",
        public: bool = False,
        exportSettings: dict = {},
        strictValidation: bool = True,
        validate: bool = False,
        sections: dict = {},
        soundLayer: str = "default",
    ) -> Item:
        counts = sum([1 for i in [speechId, scriptId, speechItem] if i])
        if counts != 1:
            raise Exception(
                "only 1 of the following is required; speechId, speechItem, or scriptId"
            )

        if speechItem:
            speechId = speechItem.speechId

        if not isinstance(soundTemplate, str):
            raise Exception("soundTemplate argument should be a string")
        if not isinstance(masteringPreset, str):
            raise Exception("masteringPreset should be a string")
        if not isinstance(sections, dict):
            raise Exception("sections should be a dict")

        body = {
            "soundTemplate": soundTemplate,
            "mediaFiles": mediaFiles,
            "fxFiles": fxFiles,
            "sectionProperties": sectionProperties,
            "timelineProperties": timelineProperties,
            "soundLayer": soundLayer,
            "sections": sections,
            "masteringPreset": masteringPreset,
            "public": public,
            "exportSettings": exportSettings,
            "strictValidation": strictValidation,
        }
        if speechId:
            body["speechId"] = speechId
        elif scriptId:
            body["scriptId"] = scriptId

        if validate:
            r = Mix.interface.send_request(
                rtype=RequestTypes.POST, route="validate", json=body
            )
        else:
            r = Mix.interface.send_request(
                rtype=RequestTypes.POST, route="mix", json=body
            )

        while r["statusCode"] == 202:
            print("Response in progress please wait...")
            r = Mix.interface.send_request(
                rtype=RequestTypes.GET,
                route="mix",
                path_parameters=r["data"]["productionId"],
            )

        return Mix.Item(r)

    @staticmethod
    def get(productionId: str) -> Item:
        r = Mix.interface.send_request(
            rtype=RequestTypes.GET, route="mix", path_parameters=productionId
        )
        return Mix.Item(r)

    @staticmethod
    def delete(productionId: str) -> APIResponseItem:
        r = Mix.interface.send_request(
            rtype=RequestTypes.DELETE, route="mix", path_parameters=productionId
        )
        return APIResponseItem(r)

    @staticmethod
    def list(
        projectName: str = "",
        moduleName: str = "",
        scriptName: str = "",
        scriptId: str = "",
    ) -> "Mix.List":
        query_params = {
            "projectName": projectName,
            "moduleName": moduleName,
            "scriptName": scriptName,
            "scriptId": scriptId,
        }

        r = Mix.interface.send_request(
            rtype=RequestTypes.GET, route="mixes", query_parameters=query_params
        )
        return Mix.List(r, list_type="productionIds")

    @staticmethod
    def list_presets() -> "Mix.List":
        r = Mix.interface.send_request(
            rtype=RequestTypes.GET, route="mix/presets", path_parameters=""
        )
        return Mix.List(response=r, list_type="presets")



from unittest.mock import Mock, patch

import pytest

import audiostack
from audiostack.helpers.request_interface import RequestInterface


@patch("audiostack.helpers.request_interface.open")
@patch("audiostack.helpers.request_interface.shutil")
@patch("audiostack.helpers.request_interface.requests")
def test_RequestInterface_download_url(
    mock_requests: Mock, mock_shutil: Mock, mock_open: Mock, tmp_path: str
) -> None:
    mock_requests.get.return_value.status_code = 200

    RequestInterface.download_url(url="foo", name="bar", destination=tmp_path)
    mock_requests.get.assert_called_once_with(
        url="foo",
        stream=True,
        headers={
            "x-api-key": audiostack.api_key,
            "x-python-sdk-version": audiostack.sdk_version,
        },
    )
    mock_open.assert_called_once_with(f"{tmp_path}/bar", "wb")
    mock_shutil.copyfileobj.assert_called_once()


@patch("audiostack.helpers.request_interface.open")
@patch("audiostack.helpers.request_interface.shutil")
@patch("audiostack.helpers.request_interface.requests")
def test_RequestInterface_download_url_assume_org(
    mock_requests: Mock, mock_shutil: Mock, mock_open: Mock, tmp_path: str
) -> None:
    mock_requests.get.return_value.status_code = 200
    audiostack.assume_org_id = "child_org_id"  # type: ignore
    RequestInterface.download_url(url="foo", name="bar", destination=tmp_path)
    mock_requests.get.assert_called_once_with(
        url="foo",
        stream=True,
        headers={
            "x-api-key": audiostack.api_key,
            "x-python-sdk-version": audiostack.sdk_version,
            "x-assume-org": "child_org_id",
        },
    )
    mock_open.assert_called_once_with(f"{tmp_path}/bar", "wb")
    mock_shutil.copyfileobj.assert_called_once()

    # Resetting value after test
    audiostack.assume_org_id = None  # type: ignore


@patch("audiostack.helpers.request_interface.requests")
def test_RequestInterface_download_url_4XX(
    mock_requests: Mock,
) -> None:
    mock_requests.get.return_value.status_code = 400
    with pytest.raises(Exception):
        RequestInterface.download_url(url="foo", name="bar", destination="baz")



import os

import audiostack
from audiostack.delivery.video import Video

audiostack.api_base = os.environ.get("AUDIO_STACK_DEV_URL", "https://v2.api.audio")
audiostack.api_key = os.environ["AUDIO_STACK_DEV_KEY"]  # type: ignore

test_constants = {}  # type: dict

if "staging" in audiostack.api_base:
    FILE_IDS = {
        "video": "e655867d-c12f-42ad-a57e-466598ab84aa",
        "audio": "11c7fcf7-d7cd-4c83-ba6b-a383a6d16a30",
    }
else:
    FILE_IDS = {
        "video": "87c3399e-4c92-4bb5-8e95-e39564afc09a",
        "audio": "04200ee6-d74f-4f46-adbd-90c7453beede",
    }


def test_create_from_production_and_image() -> None:
    script = audiostack.Content.Script.create(scriptText="hello sam")
    speech = audiostack.Speech.TTS.create(scriptItem=script, voice="sara")
    mix = audiostack.Production.Mix.create(speechItem=speech)
    print(mix)

    video = Video.create_from_production_and_image(
        productionItem=mix,
        public=True,
    )
    print(video)
    assert video.status_code == 200, "Video from production and image Failed"


def test_create_from_production_and_video() -> None:
    script = audiostack.Content.Script.create(scriptText="hello lars")
    speech = audiostack.Speech.TTS.create(scriptItem=script, voice="sara")
    mix = audiostack.Production.Mix.create(speechItem=speech)

    videoFileId = FILE_IDS["video"]
    mode = {"setting": "low"}

    video = Video.create_from_production_and_video(
        productionItem=mix,
        videoFileId=videoFileId,
        public=True,
        mode=mode,
    )
    print(video)
    assert video.status_code == 200, "Video from production and video Failed"


def test_create_from_file_and_video() -> None:
    fileId = FILE_IDS["audio"]
    videoFileId = FILE_IDS["video"]
    mode = {"setting": "low"}

    video = Video.create_from_file_and_video(
        fileId=fileId, videoFileId=videoFileId, mode=mode
    )
    print(video)
    assert video.status_code == 200, "Video from file and video Failed"


def test_create_from_file_and_image() -> None:
    fileId = FILE_IDS["audio"]

    video = Video.create_from_file_and_image(fileId=fileId)
    print(video)
    assert video.status_code == 200, "Video from file and image"
